@@ -8,10 +8,17 @@ use utf8;
 use namespace::autoclean;
 use Moose;
 extends qw(MooseX::App::Message::Block);
+no if $] >= 5.018000, warnings => qw(experimental::smartmatch);
 
 use Term::ANSIColor qw();
 use IO::Interactive qw(is_interactive);
 
+BEGIN {
+    if ($^O eq 'MSWin32') {
+        Class::Load::try_load_class('Win32::Console::ANSI');
+    }
+};
+
 sub stringify {
     my ($self) = @_;
     
