@@ -16,7 +16,7 @@ has extra_argv => (
 has 'help_flag' => (
     is              => 'ro', 
     isa             => 'Bool',
-    traits          => ['AppOption'],
+    traits          => ['MooseX::App::Meta::Role::Attribute::Option'],
     cmd_flag        => 'help',
     cmd_aliases     => [ qw(h usage ?) ], # LOCALIZE
     cmd_type        => 'proto',
